@@ -9,7 +9,7 @@ use Encode;
 use Amazon::S3::Thin::Resource;
 use Amazon::S3::Thin::Credentials;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 my $METADATA_PREFIX      = 'x-amz-meta-';
 my $MAIN_HOST = 's3.amazonaws.com';
@@ -202,7 +202,8 @@ sub delete_multiple_objects {
     my ($self, $bucket, @keys) = @_;
 
     my $content = _build_xml_for_delete(@keys);
-    my $resource = $self->_resource($bucket, undef, 'delete');
+    # XXX: specify an empty string with `delete` query for calculating signature correctly in AWS::Signature4
+    my $resource = $self->_resource($bucket, undef, 'delete=');
     my $request = $self->_compose_request(
         'POST',
         $resource,
